

#include <tmgdir.h>
#include <sys/mount.h>
#include <dirent.h>
#include <string.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <sys/vfs.h>
#include <errno.h>

int TmgDir::printDirectory(std::string path, std::vector<std::string> &directory, 
                           DirOpts opts, std::string extmask) {
    DIR *dp;
    char cwd[4096];
    struct dirent *entry;
    struct stat statbuf;

    if((dp = opendir(path.c_str())) == NULL) {
        return -1;
    }
    
    if (path[path.size() - 1] != '/') {
        path += "/";
    }

    getcwd(cwd, 4096);
    chdir(path.c_str());

    // make sure the user doesn't give us a 
    // vector with data in already
    directory.clear();
    
    // set the bit in opts, rather than checking the size
    // each time
    if (extmask.size()) {
        opts = (DirOpts)(opts | EXT_MASK);
    }
    
    while((entry = readdir(dp)) != NULL) {
        lstat(entry->d_name,&statbuf);

        if (S_ISDIR(statbuf.st_mode) && findDirs(opts)) {
            
            if (!strcmp(entry->d_name, ".") || !strcmp(entry->d_name, "..")) {
                // don't include these, they're in every dir
            }
            else if (fullPath(opts)) {
                directory.push_back(path + std::string(entry->d_name));
            }
            else {
                directory.push_back(entry->d_name);
            }
        }
        else if (findFiles(opts)) {
            if (fullPath(opts)) {
                if (!strcmp(entry->d_name, ".") || !strcmp(entry->d_name, "..")) {
                // don't include these, they're in every dir
                }
                else if (findExt(opts) && std::string(entry->d_name).find(extmask) 
                        < std::string(entry->d_name).size()) {
                    directory.push_back(path + std::string(entry->d_name));
                }
                else {
                    directory.push_back(path + std::string(entry->d_name));
                }
            }
            else {
                if (!strcmp(entry->d_name, ".") || !strcmp(entry->d_name, "..")) {
                // don't include these, they're in every dir
                }
                else if (extmask.size() && std::string(entry->d_name).find(extmask) 
                        < std::string(entry->d_name).size()) {
                    directory.insert(directory.end(), entry->d_name);
                }
                else if (!extmask.size()) {
                    directory.insert(directory.end(), entry->d_name);
                }
            }
        }
    }

    // sort the values
    sort(directory.begin(), directory.end());

    // set the directory back to the previous
    chdir(cwd);
    closedir(dp);
    
    return 0;
}


std::string TmgDir::getExtension(std::string str) {
    int pos(str.size() - 1);
    // start at the back and work front
    while (pos > 0 && str[--pos] != '.');
    if (pos == 0) {
        return "";
    }
    return str.substr(pos, str.size());
}


