
/*	Copyright (C) 2005, 2006 by Andy Grebe a.k.a. tecknophreak(tecknophreak@gmail.com)
 *
 *	This file is part of TouchMe Games.
 *
 *	TouchMe Games is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	TouchMe Games is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with TouchMe Games; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef TOUCHME_GAMES_H
#define TOUCHME_GAMES_H

#include <map>

#include <gtk/gtk.h>
#include <touchmegames.h>
#include <gameptr.h>

// Includes for each game
//#include <demo.h>
#include <gorillathrilla.h>
#include <videopoker.h>
#include <flogthedolphin.h>
// commented out until a board is created
// #include <dart01.h>
// #include <dartCountUp.h>
// #include <darttictactoe.h>
// #include <dartlowball.h>
// #include <dartcountdown.h>
// #include <dartcricket.h>
// #include <dartcricket10.h>
#include <foxyboxy.h>
#include <wordhunt.h>
#include <threescompany.h>
#include <tritowers.h>
#include <compile4.h>
#include <secretphrase.h>
#include <consume21.h>
#include <sudoku.h>



#define VERSION "0.2.0"

class TOUCHME_GAMES {
private:
    GtkWidget *topWindow;
    GtkWidget *topHbox;
    GtkWidget *topVbox;
    GtkWidget *selectBox;
    GtkWidget *gameSelectFixed;
    GtkWidget *startButton, *aboutButton;
    GtkWidget *previewBox;
    GtkWidget *previewTable;
    GtkWidget *previewBg;
    GtkWidget *lastGameSelected;
    GtkWidget *mainMenu;
    GtkWidget *menuCaptions[5];
    GtkWidget *menuWidgets[5];
    GtkWidget *gameTable;
    GtkWidget *aboutBox;
    GtkWidget *aboutImage;
    GtkWidget *mainBack;
    GtkWidget *mainAbout;
    GtkWidget *bgImage;
    GtkWidget *gameBg;
    
    TmgWave tmgWave;
//    DartLib dart;
    
    // Instance of each game.
    //DEMO demo;
    GORILLA_THRILLA gorillathrilla;
    VIDEO_POKER videopoker;
    FLOG_THE_DOLPHIN flogthedolphin;
    // commented out until a board is created
//     DART_01 dart01;
//     DART_COUNTUP dartCountUp;
//     DartTicTacToe darttictactoe;
//     DART_LOWBALL dartlowball;
//     DartCountDown dartcountdown;
//     DartCricket dartcricket;
//     DartCricket10 dartcricket10;
    WordHunt wordhunt;
    ThreesCompany threescompany;
    TriTowers tritowers;
    FoxyBoxy foxyboxy;
    Compile4 compile4;
    SecretPhrase secretphrase;
    Consume21 consume21;
    Sudoku sudoku;
    
    std::vector<GAME_PTR *> games;
    std::map<GtkWidget *, GAME_PTR *> gameMap;
    
    GtkStyle *mainStyle;
    
    void createWindow();
    void addGamesToWindow(int gameType, int startNum);
    void createPreviewBox(GAME_PTR *);
    void createHelpBox(GAME_PTR *ptr);
    
    void createMainMenu();
    void createAbout();
    
    // events.cpp
    static void showHighScores(GtkWidget *widget, GdkEvent *event, gpointer ptr);
    static void showHelp(GtkWidget *widget, GdkEvent *event, gpointer ptr);
    static void startGame(GtkWidget *widget, GdkEvent *event, gpointer ptr);
    static void gameEnded(GtkWidget *widget, gpointer ptr);
    static void showSubMenu(GtkWidget *widget, GdkEvent *event, gpointer ptr);
    static void showMain(GtkWidget *widget, GdkEvent *event, gpointer ptr);
    static void showAbout(GtkWidget *widget, GdkEvent *event, gpointer ptr);
    static void rightArrowPressed(GtkWidget *widget, GdkEvent *event, gpointer ptr);
    static void leftArrowPressed(GtkWidget *widget, GdkEvent *event, gpointer ptr);
public:
    TOUCHME_GAMES();
    void init();
};


#endif // TOUCHME_GAMES_H
