
/*	Copyright (C) 2005, 2006 by Andy Grebe a.k.a. tecknophreak(tecknophreak@gmail.com)
 *
 *	This file is part of TouchMe Games.
 *
 *	TouchMe Games is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	TouchMe Games is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with TouchMe Games; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <videopoker.h>
#include <sstream>
#include <iomanip>


GtkWidget *VIDEO_POKER::createScoreBox() {
	GtkWidget *label;
	GtkWidget *button;
	GtkWidget *hbox;
	GtkStyle *style;
	std::stringstream sstr;
	
	hbox = gtk_hbox_new(false, 0);
	
	label = gtk_label_new("Score:");
	gtk_box_pack_start((GtkBox *)hbox, label, TRUE, FALSE, 0);
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	sstr << std::setw(10) << "$  " << 500;
	scoreLabel = gtk_label_new(sstr.str().c_str());
	gtk_box_pack_start((GtkBox *)hbox, scoreLabel, TRUE, FALSE, 0);
	style = gtk_widget_get_style(scoreLabel);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(scoreLabel, style);
	
	sstr.str("    ");
	label = gtk_label_new(sstr.str().c_str());
	gtk_box_pack_start((GtkBox *)hbox, label, TRUE, FALSE, 0);
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	label = gtk_label_new("High Score:");
	gtk_box_pack_start((GtkBox *)hbox, label, TRUE, FALSE, 0);
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	
	sstr.str("");
	sstr << std::setw(10) << "$  " << scores[0].score;
	label = gtk_label_new(sstr.str().c_str());
	gtk_box_pack_start((GtkBox *)hbox, label, TRUE, FALSE, 0);
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	sstr.str("    ");
	label = gtk_label_new(sstr.str().c_str());
	gtk_box_pack_start((GtkBox *)hbox, label, TRUE, FALSE, 0);
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	label = gtk_label_new("Hand:");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_box_pack_start((GtkBox *)hbox, label, TRUE, FALSE, 0);
	
	sstr << std::setw(10) << " 1 of 20";
	handLabel = gtk_label_new(sstr.str().c_str());
	style = gtk_widget_get_style(handLabel);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(handLabel, style);
	gtk_box_pack_start((GtkBox *)hbox, handLabel, TRUE, FALSE, 0);
	
	return hbox;
}

GtkWidget *VIDEO_POKER::createHandBox() {
	GtkWidget *label;
	GtkWidget *button;
	GtkWidget *hbox;
	GtkWidget *image;
	
	hbox = gtk_hbox_new(FALSE, 0);
	
	for (int i = 0; i < 5; ++i) {
		
		
		cardBoxes[i] = gtk_event_box_new();
		gtk_event_box_set_visible_window((GtkEventBox *)cardBoxes[i], FALSE);
		gtk_widget_add_events(cardBoxes[i], GDK_BUTTON_RELEASE_MASK);
		gtk_widget_add_events(cardBoxes[i], GDK_BUTTON_PRESS_MASK);
		gtk_widget_add_events(cardBoxes[i], GDK_BUTTON1_MOTION_MASK);
		g_signal_connect(G_OBJECT(cardBoxes[i]), "button-press-event",
				G_CALLBACK(cardSelected), (gpointer)this);
				
		gtk_widget_set_size_request(cardBoxes[i], 128, 131);
		
		cardImages[i] = gtk_image_new_from_file(deckBack.c_str());
		
		gtk_container_add((GtkContainer *)cardBoxes[i], cardImages[i]);
		
		gtk_box_pack_start((GtkBox *)hbox, cardBoxes[i], TRUE, TRUE, 0);
	}
	
	return hbox;
}

GtkWidget *VIDEO_POKER::createInstructionBox() {
	GtkStyle *style;
	GtkWidget *hbox;
	
	hbox = gtk_hbox_new(TRUE, 0);
	
	instructionLabel = gtk_label_new("Select a bet and press the deal button.");
	style = gtk_widget_get_style(instructionLabel);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(instructionLabel, style);
	gtk_box_pack_start((GtkBox *)hbox, instructionLabel, TRUE, TRUE, 0);
	
	return hbox;
}

GtkWidget *VIDEO_POKER::createBetBox() {
	GtkWidget *label;
	GtkWidget *button;
	GtkWidget *hbox;
	GtkStyle *style;
	
	hbox = gtk_hbox_new(TRUE, 0);
	
	label = gtk_label_new("Bet: ");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_box_pack_start((GtkBox *)hbox, label, TRUE, TRUE, 0);
	
	
	label = gtk_label_new("$5");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	betButtons[0] = gtk_toggle_button_new();
	gtk_container_add((GtkContainer *)betButtons[0], label);
	gtk_widget_set_size_request(betButtons[0], 100, 60);
	gtk_box_pack_start((GtkBox *)hbox, betButtons[0], TRUE, TRUE, 5);
	g_signal_connect(G_OBJECT(betButtons[0]), "toggled",
		G_CALLBACK(betPlaced), (gpointer)this);
	
	label = gtk_label_new("$10");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	betButtons[1] = gtk_toggle_button_new();
	gtk_container_add((GtkContainer *)betButtons[1], label);
	gtk_widget_set_size_request(betButtons[1], 100, 60);
	gtk_box_pack_start((GtkBox *)hbox, betButtons[1], TRUE, TRUE, 5);
	g_signal_connect(G_OBJECT(betButtons[1]), "toggled",
		G_CALLBACK(betPlaced), (gpointer)this);
	
	label = gtk_label_new("$15");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	betButtons[2] = gtk_toggle_button_new();
	gtk_container_add((GtkContainer *)betButtons[2], label);
	gtk_widget_set_size_request(betButtons[2], 100, 60);
	gtk_box_pack_start((GtkBox *)hbox, betButtons[2], TRUE, TRUE, 5);
	g_signal_connect(G_OBJECT(betButtons[2]), "toggled",
		G_CALLBACK(betPlaced), (gpointer)this);
	
	label = gtk_label_new("$20");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	betButtons[3] = gtk_toggle_button_new();
	gtk_container_add((GtkContainer *)betButtons[3], label);
	gtk_widget_set_size_request(betButtons[3], 100, 60);
	gtk_box_pack_start((GtkBox *)hbox, betButtons[3], TRUE, TRUE, 5);
	g_signal_connect(G_OBJECT(betButtons[3]), "toggled",
		G_CALLBACK(betPlaced), (gpointer)this);
	
	label = gtk_label_new("$25");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	betButtons[4] = gtk_toggle_button_new();
	gtk_container_add((GtkContainer *)betButtons[4], label);
	gtk_widget_set_size_request(betButtons[4], 100, 60);
	gtk_box_pack_start((GtkBox *)hbox, betButtons[4], TRUE, TRUE, 5);
	g_signal_connect(G_OBJECT(betButtons[4]), "toggled",
		G_CALLBACK(betPlaced), (gpointer)this);
	
	
	label = gtk_label_new("Deal");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 18 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	
	button = gtk_button_new();
	gtk_container_add((GtkContainer *)button, label);
	gtk_widget_set_size_request(button, 100, 60);
	gtk_box_pack_start((GtkBox *)hbox, button, TRUE, TRUE, 10);
	g_signal_connect(G_OBJECT(button), "released",
		G_CALLBACK(dealPressed), (gpointer)this);
	
	return hbox;
}

GtkWidget *VIDEO_POKER::createPayoutBox() {
	GtkWidget *label;
	GtkWidget *hbox;
	GtkWidget *vbox;
	GtkStyle *style;
	GtkWidget *frame;
	GtkWidget *table;
	
	hbox = gtk_hbox_new(FALSE, 0);
	//vbox = gtk_vbox_new(FALSE, 0);
	
	
	//gtk_box_pack_start((GtkBox *)hbox, vbox, FALSE, FALSE, 0);
	
	frame = gtk_frame_new(NULL);
	gtk_frame_set_shadow_type((GtkFrame *)frame, GTK_SHADOW_OUT);
	gtk_box_pack_start((GtkBox *)hbox, frame, TRUE, FALSE, 0);
	
	table = gtk_table_new(5, 4, false);
	gtk_table_set_row_spacings((GtkTable *)table, 3);
	gtk_table_set_col_spacings((GtkTable *)table, 10);
	gtk_container_add((GtkContainer *)frame, table);
	
	label = gtk_label_new("Royal Flush");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 0, 1, 0, 1);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	
	
	label = gtk_label_new("250 to 1");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 1, 2, 0, 1);
	gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
	
	
	
	label = gtk_label_new("Four Of A Kind");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 0, 1, 1, 2);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	
	label = gtk_label_new("50 to 1");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 1, 2, 1, 2);
	gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
	
	
	
	label = gtk_label_new("Straight Flush");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 0, 1, 2, 3);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	
	label = gtk_label_new("25 to 1");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 1, 2, 2, 3);
	gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
	
	
	label = gtk_label_new("Full House");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 0, 1, 3, 4);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	
	label = gtk_label_new("9 to 1");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 1, 2, 3, 4);
	gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
	
	
	
	
	label = gtk_label_new("Flush");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 0, 1, 4, 5);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	
	label = gtk_label_new("6 to 1");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 1, 2, 4, 5);
	gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
	
	
	
	label = gtk_label_new("Straight");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 2, 3, 0, 1);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	
	label = gtk_label_new("4 to 1");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 3, 4, 0, 1);
	gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
	
	
	
	
	label = gtk_label_new("Three of a Kind");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 2, 3, 1, 2);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	
	label = gtk_label_new("3 to 1");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 3, 4, 1, 2);
	gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
	
	
	
	label = gtk_label_new("Two Pair");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 2, 3, 2, 3);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	
	label = gtk_label_new("2 to 1");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 3, 4, 2, 3);
	gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
	
	
	
	label = gtk_label_new("Pair");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 2, 3, 3, 4);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	
	label = gtk_label_new("1 to 1");
	style = gtk_widget_get_style(label);
	pango_font_description_set_size(style->font_desc, 16 * PANGO_SCALE);
	gtk_widget_set_style(label, style);
	gtk_table_attach_defaults((GtkTable *)table, label, 3, 4, 3, 4);
	gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
	
	gtk_widget_show_all(hbox);
	return hbox;
}

// initializes the game's variables and returns the
// top level h/vbox
GtkWidget *VIDEO_POKER::init() {
	GtkWidget *eventBox;
	GtkWidget *image;
	topvbox = gtk_vbox_new(FALSE, 0);
	
	GAME_PTR::loadScores(scores);
	
	
	gtk_box_pack_start((GtkBox *)topvbox, createScoreBox(), FALSE, FALSE, 4);
	gtk_box_pack_start((GtkBox *)topvbox, createHandBox(), TRUE, FALSE, 4);
	gtk_box_pack_start((GtkBox *)topvbox, createInstructionBox(), FALSE, FALSE, 0);
	gtk_box_pack_start((GtkBox *)topvbox, createBetBox(), FALSE, FALSE, 7);
	gtk_box_pack_start((GtkBox *)topvbox, createPayoutBox(), FALSE, FALSE, 5);
	
	eventBox = gtk_event_box_new();
	gtk_event_box_set_visible_window((GtkEventBox *)eventBox, false);
	image = gtk_image_new_from_file("/usr/local/share/touchmegames/images/exit.gif");
	gtk_widget_add_events(eventBox, GDK_BUTTON_PRESS_MASK);
	g_signal_connect(G_OBJECT(eventBox), "button-press-event",
			 G_CALLBACK(userExit), (gpointer)this);
	gtk_container_add((GtkContainer *)eventBox, image);
	gtk_box_pack_start((GtkBox *)topvbox, eventBox, FALSE, FALSE, 0);
	
	for (int i = 0; i < 52; ++i) {
		cardDeck[i] = i;
	}
	startHand();
	currentBet = 5;
	hand = 1;
	currentScore = 500;
	timer = gtk_timeout_add(100, timeout, this);
	gtk_toggle_button_set_active((GtkToggleButton *)betButtons[currentBet / 5 - 1], true);
	gtk_widget_show_all(topvbox);
	return topvbox;
};

